@@ -3,19 +3,23 @@
 //! <https://doi.org/10.1016/j.cad.2010.12.015>
 //!
 //! This method require round function.
-use crate::{utility::*, *};
+use crate::utility::prelude::*;
 
 /// Teaching Learning Based Optimization settings.
 #[derive(Default)]
-pub struct Tlbo(pub BasicSetting);
+pub struct Tlbo(BasicSetting);
 
-impl<F: ObjFunc> Setting<F> for Tlbo {
+impl Setting for Tlbo {
     type Algorithm = Method;
 
     fn base(&self) -> &BasicSetting {
         &self.0
     }
 
+    fn base_mut(&mut self) -> &mut BasicSetting {
+        &mut self.0
+    }
+
     fn create(self) -> Self::Algorithm {
         Method
     }
