@@ -44,10 +44,15 @@ where
 
 /// A prelude module for algorithm implementation.
 ///
-/// This module includes all items of this crate,
-/// and some items from "ndarray".
+/// This module includes all items of this crate, and external items from "ndarray" and "rayon"
+/// (if `parallel` feature enabled).
 pub mod prelude {
     pub use super::*;
-    pub use crate::{random::*, thread_pool::ThreadPool, *};
-    pub use ndarray::{s, Array1, Array2, AsArray};
+    pub use crate::{random::*, *};
+    #[doc(no_inline)]
+    pub use ndarray::{s, Array1, Array2, AsArray, Axis, Zip};
+    #[cfg(feature = "parallel")]
+    #[doc(no_inline)]
+    #[cfg_attr(doc_cfg, doc(cfg(feature = "parallel")))]
+    pub use rayon::prelude::*;
 }
